@@ -21,7 +21,7 @@ class GenericPolymorphicFormSetChild(PolymorphicFormSetChild):
     def __init__(self, *args, **kwargs):
         self.ct_field = kwargs.pop("ct_field", "content_type")
         self.fk_field = kwargs.pop("fk_field", "object_id")
-        super(GenericPolymorphicFormSetChild, self).__init__(*args, **kwargs)
+        super().__init__(*args, **kwargs)
 
     def get_form(self, ct_field="content_type", fk_field="object_id", **kwargs):
         """
@@ -42,20 +42,16 @@ class GenericPolymorphicFormSetChild(PolymorphicFormSetChild):
             not isinstance(ct_field, models.ForeignKey)
             or ct_field.remote_field.model != ContentType
         ):
-            raise Exception(
-                "fk_name '%s' is not a ForeignKey to ContentType" % ct_field
-            )
+            raise Exception(f"fk_name '{ct_field}' is not a ForeignKey to ContentType")
 
         fk_field = opts.get_field(self.fk_field)  # let the exception propagate
         exclude.extend([ct_field.name, fk_field.name])
         kwargs["exclude"] = exclude
 
-        return super(GenericPolymorphicFormSetChild, self).get_form(**kwargs)
+        return super().get_form(**kwargs)
 
 
-class BaseGenericPolymorphicInlineFormSet(
-    BaseGenericInlineFormSet, BasePolymorphicModelFormSet
-):
+class BaseGenericPolymorphicInlineFormSet(BaseGenericInlineFormSet, BasePolymorphicModelFormSet):
     """
     Polymorphic formset variation for inline generic formsets
     """
@@ -130,7 +126,5 @@ def generic_polymorphic_inlineformset_factory(
         child_kwargs.update(child_form_kwargs)
 
     FormSet = generic_inlineformset_factory(**kwargs)
-    FormSet.child_forms = polymorphic_child_forms_factory(
-        formset_children, **child_kwargs
-    )
+    FormSet.child_forms = polymorphic_child_forms_factory(formset_children, **child_kwargs)
     return FormSet
